@@ -4,7 +4,7 @@ import importlib
 from typing import Any
 from typing import Dict
 from typing import Iterable
-from polygenic.lib.model.seqql import PolygenicRiskScoreResult
+from polygenic.seqql.score import PolygenicRiskScoreResult
 from polygenic.lib.data_access.dto import ModelDescriptionInfo
 
 logger = logging.getLogger('description_language.' + __name__)
